package com.xynet.marketing.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.xynet.marketing.entity.MercProjectDevice;
import com.xynet.marketing.mapper.MercProjectDeviceMapper;
import com.xynet.marketing.service.MercProjectDeviceService;
import com.xynet.marketing.utils.Emptys;
import com.xynet.marketing.utils.collections.map.JHashMap;
import com.xynet.marketing.utils.collections.map.JMap;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 项目设备服务 实现
 *
 * @author hechunping
 * @date 2025/1/20
 */
@Service
@Slf4j
public class MercProjectDeviceServiceImpl extends ServiceImpl<MercProjectDeviceMapper, MercProjectDevice> implements MercProjectDeviceService {
    private LambdaQueryWrapper<MercProjectDevice> commonQueryWrapper(JMap<String, Object> param) {
        LambdaQueryWrapper<MercProjectDevice> lqw = new LambdaQueryWrapper<MercProjectDevice>()
                .eq(Emptys.check(param.getInt("id")), MercProjectDevice::getId, param.getInt("id"));
        return lqw;
    }

    @Override
    public Map<String, Object> obj(JMap<String, Object> param) {
        LambdaQueryWrapper<MercProjectDevice> lqw = commonQueryWrapper(param).last("limit 1");
        MercProjectDevice obj = getOne(lqw);
        return JHashMap.copy(obj);
    }

    @Override
    public void saveOrUpdate(JMap<String, Object> param) {
        MercProjectDevice save = BeanUtil.copyProperties(param, MercProjectDevice.class);
        if (Emptys.check(save.getId())) {
            updateById(save);
        } else {
            save(save);
        }
    }

    @Override
    public List<Map<String, Object>> list(JMap<String, Object> param) {
        LambdaQueryWrapper<MercProjectDevice> lqw = commonQueryWrapper(param).orderByAsc(MercProjectDevice::getId);
        List<MercProjectDevice> list = list(lqw);
        return JHashMap.copy(list);
    }

    @Override
    public Page<Map<String, Object>> page(JMap<String, Object> param) {
        LambdaQueryWrapper<MercProjectDevice> lqw = commonQueryWrapper(param).orderByAsc(MercProjectDevice::getId);
        Page<MercProjectDevice> page = new Page<>(param.getInt("pageCurrent"), param.getInt("pageSize"), true);
        Page<MercProjectDevice> list = page(page, lqw);
        return JHashMap.copy(list);
    }

    @Override
    public void removeByActId(Integer actId) {
        LambdaQueryWrapper<MercProjectDevice> lqw = new LambdaQueryWrapper<MercProjectDevice>()
                .eq(MercProjectDevice::getActId, actId);
        remove(lqw);
    }

    @Override
    public void saveBatchByActId(Integer actId, String actType, List<JMap<String, Object>> goodsList) {
        List<MercProjectDevice> saveDeviceList = new ArrayList<>();
        goodsList.forEach(goods -> {
            goods.put("actId", actId);
            goods.put("actType", actType);
            MercProjectDevice saveGoods = BeanUtil.copyProperties(goods, MercProjectDevice.class);
            saveDeviceList.add(saveGoods);
        });
        saveBatch(saveDeviceList);
    }

    @Override
    public List<Map<String, Object>> listByActId(Integer actId, String actType) {
        LambdaQueryWrapper<MercProjectDevice> lqw = new LambdaQueryWrapper<MercProjectDevice>()
                .eq(MercProjectDevice::getActId, actId)
                .eq(MercProjectDevice::getActType, actType);
        return JHashMap.copy(list(lqw));
    }
}
